@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.34 2001/02/24 12:38:02 bazsi Exp $
+ * $Id: affile.c,v 1.36 2001/04/14 08:02:17 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -78,6 +78,7 @@ static int do_open_file(struct ol_string *name, int flags,
 				if (mkdir(name->data, dir_mode) == -1)
 					return 0;
 				chown(name->data, dir_uid, dir_gid);
+				chmod(name->data, dir_mode);
 			}
 			*p = '/';
 			p = strchr(p + 1, '/');
@@ -85,6 +86,7 @@ static int do_open_file(struct ol_string *name, int flags,
 		*fd = open(name->data, flags, mode);
 	}
 	chown(name->data, uid, gid);
+	chmod(name->data, mode);
 	return *fd != -1;
 }
 
