@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afunix.c,v 1.16 2001/02/24 12:38:02 bazsi Exp $
+ * $Id: afunix.c,v 1.17 2001/05/04 12:37:43 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -367,7 +367,7 @@ static int do_init_afunix_dest(struct log_handler *c,
 		CAST(unix_address_info, unix_addr, self->super.dest_addr);
 
 		close(fd);
-		werror("Error connecting AF_UNIX socket (%S): %z\n", unix_addr->path, strerror(errno));
+		werror("Error connecting to AF_UNIX(%S): %z\n", unix_addr->path, strerror(errno));
 	}
 	return ST_FAIL | ST_QUIT;
 }
@@ -378,6 +378,7 @@ do_afunix_dest_connected(struct afsocket_dest *c,
 {
 	CAST(afunix_dest, self, c);
 	struct resource_node *n;
+	CAST(unix_address_info, unix_addr, self->super.dest_addr);
 
 	if (!self->cfg->living) {
 		werror("Connection established for an old configuration, dropping...\n");
@@ -392,10 +393,10 @@ do_afunix_dest_connected(struct afsocket_dest *c,
 				      self->dest_buf,
 				      make_driver_reinit_on_close
 				      (&self->super.super.super, n, 
-				       self->cfg->time_reopen, self->cfg));
+				       self->cfg->time_reopen, self->cfg,
+				       c_format("AF_UNIX(%S)", unix_addr->path)));
 	}
 	else {
-		CAST(unix_address_info, unix_addr, self->super.dest_addr);
 
 		werror("Error connecting to remote AF_UNIX socket (%S), reattempting in %i seconds\n", unix_addr->path, self->cfg->time_reopen);
 		self->dest = NULL;
