@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: main.c,v 1.31 2001/05/04 12:37:43 bazsi Exp $
+ * $Id: main.c,v 1.32 2001/05/14 09:07:25 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -232,7 +232,7 @@ int resolve_user_group(char *arg, uid_t *uid, gid_t *gid)
 	group = strtok(NULL, "");
 	if (user) {
 		pw = getpwnam(user);
-		if (!pw) {
+		if (pw) {
 			*uid = pw->pw_uid;
 		}
 		else {
@@ -247,7 +247,7 @@ int resolve_user_group(char *arg, uid_t *uid, gid_t *gid)
 	if (group && gid) {
 		*gid = 0;
 		gr = getgrnam(group);
-		if (!gr) {
+		if (gr) {
 			*gid = gr->gr_gid;
 		}
 		else {
@@ -265,7 +265,7 @@ int resolve_group(char *group, gid_t *gid)
 
 	*gid = 0;
 	gr = getgrnam(group);
-	if (!gr) {
+	if (gr) {
 		*gid = gr->gr_gid;
 	}
 	else {
